<div class="equal width field">
  <div class="ui calendar time" id="date_{{ widget.name }}">
    <div class="ui input left icon">
      <i class="clock icon"></i> 
      {% include "semantic_ui/forms/widgets/input_autocomplete_off.html" %}
    </div>
  </div>
</div>
