{% load i18n static %}
<div class="ui fluid related-widget">
{{ rendered_widget }}
</div>
<div class="related-widget-wrapper">
    {% block links %}
        {% spaceless %}
        {% if can_change_related %}
        <a class="related-widget-wrapper-link change-related" id="change_id_{{ name }}"
            data-href-template="{{ change_related_template_url }}?{{ url_params }}"
            title="{% blocktrans %}Change selected {{ model }}{% endblocktrans %}">
            <i style="color: rgba(0,0,0,.87);" class="pencil icon" title="{% trans 'Change' %}"></i>
        </a>
        {% endif %}
        {% if can_add_related %}
        <a class="related-widget-wrapper-link add-related" id="add_id_{{ name }}"
            href="{{ add_related_url }}?{{ url_params }}"
            title="{% blocktrans %}Add another {{ model }}{% endblocktrans %}">
            <i style="color: rgba(0,0,0,.87);" class="plus icon" title="{% trans 'Add' %}"></i>
        </a>
        {% endif %}
        {% if can_delete_related %}
        <a class="related-widget-wrapper-link delete-related" id="delete_id_{{ name }}"
            data-href-template="{{ delete_related_template_url }}?{{ url_params }}"
            title="{% blocktrans %}Delete selected {{ model }}{% endblocktrans %}">
            <i style="color: rgba(0,0,0,.87);" class="x icon" title="{% trans 'Delete' %}"></i>
        </a>
        {% endif %}
        {% endspaceless %}
    {% endblock %}
</div>
