{% if widget.is_initial %}{{ widget.initial_text }}: <a href="{{ widget.value.url }}">{{ widget.value }}</a>

{% if not widget.required %}
<div class="ui checkbox" style="margin-left: 0.25em;">
  <input type="checkbox" name="{{ widget.checkbox_name }}" id="{{ widget.checkbox_id }}"{% if widget.attrs.disabled %} disabled{% endif %} /><label for="{{ widget.checkbox_id }}">{{ widget.clear_checkbox_label }}</label>
</div>
{% endif %}
<br />
{{ widget.input_text }}:{% endif %}
<input type="{{ widget.type }}" name="{{ widget.name }}"{% include "django/forms/widgets/attrs.html" %}/>
