<div class="ui basic segment" style="margin-top: 0;">
  <div class="ui form noprint">
    <div class="equal width fields">
      <!-- Delete button -->
      <div class="field">{% include "admin/delete_button.html" %}</div>
      <!-- END Delete button -->

      <!-- Save Buttons -->
      {% include "admin/save_buttons.html" %}
      <!-- END Save Buttons -->
    </div>
  </div>
</div>