<div class="field">
  <div class="ui radio checkbox">
  {% include "django/forms/widgets/input.html" %}
  <label{% if widget.attrs.id %} for="{{ widget.attrs.id }}"{% endif %}>{{ widget.label }}</label>
  </div>
</div>
