{% load i18n %}
{% if show %}
<h2 style="margin-top: 0; padding-left: 1rem;" class="ui header">{% trans 'Date filter' %}</h2>
<div class="ui secondary segment">
  <div class="ui horizontal list">
    {% block date-hierarchy-toplinks %}
    {% block date-hierarchy-back %}
    {% if back %}<div class="item"><a href="{{ back.link }}">&lsaquo; {{ back.title }}</a></div>{% endif %}
    {% endblock %}
    {% block date-hierarchy-choices %}
    {% for choice in choices %}
    <div class="item"> {% if choice.link %}<a href="{{ choice.link }}">{% endif %}{{ choice.title }}{% if choice.link %}</a>{% endif %}</div>
    {% endfor %}
    {% endblock %}
    {% endblock %}
  </div>
</div>
{% endif %}
