{% load i18n admin_urls static admin_modify %}
<div class="js-inline-admin-formset inline-group" id="{{ inline_admin_formset.formset.prefix }}-group"
     data-inline-type="tabular"
     data-inline-formset="{{ inline_admin_formset.inline_formset_data }}">
  <div class="tabular inline-related {% if forloop.last %}last-related{% endif %}">
{{ inline_admin_formset.formset.management_form }}
  
{# BEGIN CUSTOMIZATION <fieldset class="module {{ inline_admin_formset.classes }}"> #}
<h2 style="margin-left: 1rem;" >{{ inline_admin_formset.opts.verbose_name_plural|capfirst }}</h2>
{# END CUSTOMIZATION #}

 {{ inline_admin_formset.formset.non_form_errors }}

 {# BEGIN CUSTOMIZATION #}
 <table class="ui celled table">
 {# END CUSTOMIZATION #}

   <thead><tr>
       <th class="original" {# comment style="visibility: hidden;" #}></th>
   {% for field in inline_admin_formset.fields %}
     {% if not field.widget.is_hidden %}
       <th{% if field.required %} class="required"{% endif %}>{{ field.label|capfirst }}
       {% if field.help_text %}&nbsp;<img src="{% static "admin/img/icon-unknown.svg" %}" class="help help-tooltip" width="10" height="10" alt="({{ field.help_text|striptags }})" title="{{ field.help_text|striptags }}">{% endif %}
       </th>
     {% endif %}
   {% endfor %}
   {% if inline_admin_formset.formset.can_delete %}<th>{% trans "Delete?" %}</th>{% endif %}
   </tr></thead>

   <tbody>
   {% for inline_admin_form in inline_admin_formset %}
      {% if inline_admin_form.form.non_field_errors %}
      <tr><td colspan="{{ inline_admin_form|cell_count }}">{{ inline_admin_form.form.non_field_errors }}</td></tr>
      {% endif %}
      <tr class="form-row {% cycle "row1" "row2" %} {% if inline_admin_form.original or inline_admin_form.show_url %}has_original{% endif %}{% if forloop.last and inline_admin_formset.has_add_permission %} empty-form{% endif %}"
           id="{{ inline_admin_formset.formset.prefix }}-{% if not forloop.last %}{{ forloop.counter0 }}{% else %}empty{% endif %}">
      <td class="original">
        {% if inline_admin_form.original or inline_admin_form.show_url %}<p>
        {% if inline_admin_form.original %}
        {{ inline_admin_form.original }}
        {% if inline_admin_form.model_admin.show_change_link and inline_admin_form.model_admin.has_registered_model %}<a href="{% url inline_admin_form.model_admin.opts|admin_urlname:'change' inline_admin_form.original.pk|admin_urlquote %}" class="{% if inline_admin_formset.has_change_permission %}inlinechangelink{% else %}inlineviewlink{% endif %}">{% if inline_admin_formset.has_change_permission %}{% trans "Change" %}{% else %}{% trans "View" %}{% endif %}</a>{% endif %}
        {% endif %}
        {% if inline_admin_form.show_url %}<a href="{{ inline_admin_form.absolute_url }}">{% trans "View on site" %}</a>{% endif %}
          </p>{% endif %}
        {% if inline_admin_form.needs_explicit_pk_field %}{{ inline_admin_form.pk_field.field }}{% endif %}
        {% if inline_admin_form.fk_field %}{{ inline_admin_form.fk_field.field }}{% endif %}
        {% spaceless %}
        {% for fieldset in inline_admin_form %}
          {% for line in fieldset %}
            {% for field in line %}
              {% if not field.is_readonly and field.field.is_hidden %}{{ field.field }}{% endif %}
            {% endfor %}
          {% endfor %}
        {% endfor %}
        {% endspaceless %}
      </td>
      {% for fieldset in inline_admin_form %}
        {% for line in fieldset %}
          {% for field in line %}
            {% if field.is_readonly or not field.field.is_hidden %}
            <td{% if field.field.name %} class="field-{{ field.field.name }}"{% endif %}>
            {% if field.is_readonly %}
                <p>{{ field.contents }}</p>
            {% else %}
                {{ field.field.errors.as_ul }}
                {% if field.is_checkbox %}<div class="ui checkbox">{% endif %}
                {{ field.field }}
                {% if field.is_checkbox %}</div>{% endif %}
            {% endif %}
            </td>
            {% endif %}
          {% endfor %}
        {% endfor %}
      {% endfor %}
      {% if inline_admin_formset.formset.can_delete %}
      <td class="delete">{% if inline_admin_form.original %}<div class="ui checkbox">{{ inline_admin_form.deletion_field.field }}</div>{% endif %}</td>
      {% endif %}
      </tr>
   {% endfor %}
   </tbody>
 </table>

{# BEGIN CUSTOMIZATION </fieldset> END CUSTOMIZATION #}
  </div>
</div>
