/* Also note: https://github.com/Semantic-Org/Semantic-UI/issues/1114 */

html,
body,
#app-menu,
.ui.sidebar {
  min-height: 100%;
}

/* TODO: Fix this */
.ui.radio.checkbox {
  margin-top: 0 !important;
}

.help:not(.help-tooltip) {
  padding-top: 0.5em;
}

.hidden, .empty-form {
  display: none !important;
}

@media only screen and (max-width: 767.98px) {
  .ui.table:not(.unstackable) > tbody> tr.empty-form {
    display: none !important;
  }
}

/* CHECKBOX */

div.ui.checkbox:not(.changelist) {
  margin-bottom: 0.69em;
}

/* END CHECKBOX */

/* ACTIONS  */

@media (max-width: 767px) {
  div.actions {
    margin-bottom: 0 !important;
  } 

  div.actions > label {
    margin-bottom: 0.28571429rem !important; /* Same as non-inline form */
  }

  div.actions > div.field {
    margin-bottom: 0 !important;
  }

  div.actions > div.field > button {
    margin-top: 1rem !important;
  }

  span.action-counter {
    margin-top: 1rem !important;
  }
}

@media (min-width: 768px) {
  div.actions > div.field  {
    margin-left: 1rem !important;
  }
}

/* END ACTIONS */

/* ACTION CHECKBOX */

th.action-checkbox-column,
td.action-checkbox {
  width: 3.875rem;
}

@media (min-width: 768px) {
  th.action-checkbox-column,
  td.action-checkbox {
    text-align: center !important;
  }
}

@media (max-width: 767px) {
  th.action-checkbox-column,
  td.action-checkbox {
    text-align: auto !important;
  }
}

div#action-toggle, div.action-select {
  max-width: 1.25rem;
  margin-bottom: 0 !important;
}

/* END ACTION CHECKBOX */

@media print {
  .noprint {
    display: none !important;
    height: 0 !important;
    border: 0 none !important;
    opacity: 0 !important;
  }
}
